@@ -2,6 +2,7 @@ from calendar import timegm
 from django.test.client import RequestFactory
 from django.test import TestCase
 from django.conf.urls import patterns, url
+from restlib2.params import Parametizer, param_cleaners
 from restlib2.resources import Resource
 from restlib2.mixins import TemplateResponseMixin
 from restlib2.http import codes
@@ -425,3 +426,34 @@ class TemplateResourceTestCase(TestCase):
         response = self.client.get('/')
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.content, '<h1>Hello from testserver</h1>\n')
+
+
+class ParametizerTestCase(TestCase):
+    def test_base(self):
+        p = Parametizer()
+        self.assertEqual(p.clean(), {})
+        self.assertEqual(p.clean({}), {})
+        self.assertEqual(p.clean({}, {}), {})
+        self.assertEqual(p.clean({}, {'foo': 1}), {'foo': 1})
+        self.assertEqual(p.clean({'foo': 1}), {'foo': 1})
+        self.assertEqual(p.clean({'foo': 2}, {'foo': 1, 'bar': 1}),
+            {'foo': 2, 'bar': 1})
+
+    def test(self):
+        class P(Parametizer):
+            page = 1
+            query = ''
+
+            def clean_page(self, value):
+                return param_cleaners.clean_int(value)
+
+            def clean_query(self, value):
+                return param_cleaners.clean_string(value)
+
+        p = P()
+
+        self.assertEqual(p.clean(), {'page': 1, 'query': ''})
+        self.assertEqual(p.clean({'page': '2'}), {'page': 2, 'query': ''})
+        self.assertEqual(p.clean({'query': '  foo '}), {'page': 1, 'query': 'foo'})
+        self.assertEqual(p.clean({'something': 'else'}),
+            {'page': 1, 'query': '', 'something': 'else'})
